import React, { useContext } from 'react'
import Header from '../components/header'
import Services from '../components/services'
import Prefooter from '../components/pre_footer'
import Footer from '../components/footer'
import PendoContext from '../state/PendoContext'


export default function CartPage() {

    const { cart, removeCart, increaseQty, decreaseQty } = useContext(PendoContext)
    return <>
        <Header />
        <div className="breadcrumbs">
            <div className="container">
                <div className="row">
                    <div className="col-12">
                        <div className="bread-inner">
                            <ul className="bread-list">
                                <li><a href="/">Home<i className="ri-arrow-right-line"></i></a></li>
                                <li className="active"><a href="/cart">Cart</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div className="shopping-cart section">
            <div className="container">
                <div className="row">
                    <div className="col-12">
                        <table className="table shopping-summery">
                            <thead>
                                <tr className="main-hading">
                                    <th>PRODUCT</th>
                                    <th>NAME</th>
                                    <th className="text-center">UNIT PRICE</th>
                                    <th className="text-center">QUANTITY</th>
                                    <th className="text-center">TOTAL</th>
                                    <th className="text-center"><i className="ti-trash remove-icon"></i></th>
                                </tr>
                            </thead>
                            <tbody>
                                {
                                    cart.map(item => {
                                        return <tr key={item.id}>
                                            <td className="image" data-title="No"><img src={`images/${item.image}`} width="100" height="100" alt="#" /></td>
                                            <td className="product-des" data-title="Description">
                                                <p className="product-name"><a href="/#">{item.name}</a></p>
                                                <p className="product-des">{item.description}</p>
                                            </td>
                                            <td className="price" data-title="Price"><span>Ksh {item.price}</span></td>
                                            <td className="qty" data-title="Qty">
                                                <div className="input-group">
                                                    <div className="button minus">
                                                        <button type="button" className="btn btn-primary btn-number" onClick={() => decreaseQty(item.id)} >
                                                            <i className="ri-subtract-line"></i>
                                                        </button>
                                                    </div>
                                                    <input type="text" className="input-number" value={item.quantity} readOnly />
                                                    <div className="button plus">
                                                        <button type="button" className="btn btn-primary btn-number" onClick={() => increaseQty(item.id)}>
                                                            <i className="ri-add-fill"></i>
                                                        </button>
                                                    </div>
                                                </div>
                                            </td>
                                            <td className="total-amount" data-title="Total"><span>Ksh {item.price * item.quantity}</span></td>
                                            <td className="action"><i onClick={() => removeCart(item.id)} className="ri-delete-bin-2-line"></i></td>
                                        </tr>

                                    })
                                }
                            </tbody>
                        </table>
                    </div>
                </div>
                <div className="row">
                    <div className="col-12">
                        <div className="total-amount">
                            <div className="row">
                                <div className="col-lg-8 col-md-5 col-12">
                                    <div className="left">

                                    </div>
                                </div>
                                <div className="col-lg-4 col-md-7 col-12">
                                    <div className="right">
                                        <ul>
                                            <li className="last">You Pay<span>Ksh {cart.map(item => parseInt(item.price) * item.quantity).reduce((a, c) => a + c, 0)}</span></li>
                                        </ul>
                                        <div className="button5">
                                            <a href="/#" className="btn">Checkout</a>
                                            <a href="/#" className="btn">Continue shopping</a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <Services />
        <Prefooter />
        <Footer />
    </>
}